@@ -1,25 +1,15 @@
 /*
   This file is part of KAddressBook.
 
-  Copyright (c) 2007 Tobias Koenig <tokoe@kde.org>
+  SPDX-FileCopyrightText: 2007 Tobias Koenig <tokoe@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "mainwidget.h"
 
+#include "stylecontactlistdelegate.h"
+#include "contactinfoproxymodel.h"
 #include "contactswitcher.h"
 #include "globalcontactmodel.h"
 #include "modelcolumnmanager.h"
@@ -32,11 +22,16 @@
 #include "kaddressbook_options.h"
 #include "manageshowcollectionproperties.h"
 
-#include <KaddressbookGrantlee/GrantleeContactFormatter>
-#include <KaddressbookGrantlee/GrantleeContactGroupFormatter>
+#include "importexport/pluginmanager.h"
+#include "importexport/plugin.h"
+#include "importexport/plugininterface.h"
+#include "importexport/contactselectiondialog.h"
+
+#include <Akonadi/Contact/GrantleeContactFormatter>
+#include <Akonadi/Contact/GrantleeContactGroupFormatter>
 #include <GrantleeTheme/GrantleeThemeManager>
 
-#include <Libkdepim/UiStateSaver>
+#include "uistatesaver.h"
 
 #include <PimCommonAkonadi/ImapAclAttribute>
 #include <PimCommonAkonadi/MailUtil>
@@ -56,10 +51,6 @@
 #include <QPointer>
 #include <PimCommonAkonadi/ManageServerSideSubscriptionJob>
 #include <PimCommon/PimUtil>
-#include <KAddressBookImportExport/KAddressBookImportExportPluginManager>
-#include <KAddressBookImportExport/KAddressBookImportExportPlugin>
-#include <KAddressBookImportExport/KAddressBookImportExportPluginInterface>
-#include <KAddressBookImportExport/KAddressBookContactSelectionDialog>
 
 #include <Akonadi/Contact/ContactDefaultActions>
 #include <Akonadi/Contact/ContactGroupEditorDialog>
@@ -150,7 +141,6 @@ MainWidget::MainWidget(KXMLGUIClient *guiClient, QWidget *parent)
     QDBusConnection::sessionBus().registerObject(QStringLiteral("/KAddressBook"), this);
 
     mManageShowCollectionProperties = new ManageShowCollectionProperties(this, this);
-    mImportExportPluginManager = KAddressBookImportExport::KAddressBookImportExportPluginManager::self();
 
     Akonadi::AttributeFactory::registerAttribute<PimCommon::ImapAclAttribute>();
 
@@ -219,7 +209,7 @@ MainWidget::MainWidget(KXMLGUIClient *guiClient, QWidget *parent)
     mCollectionTree->setHeaderGroup(Akonadi::EntityTreeModel::CollectionTreeHeaders);
 
     mCollectionSelectionModel = new QItemSelectionModel(mCollectionTree);
-    StructuralCollectionsNotCheckableProxy *checkableProxyModel
+    auto *checkableProxyModel
         = new StructuralCollectionsNotCheckableProxy(this);
     checkableProxyModel->setSelectionModel(mCollectionSelectionModel);
     checkableProxyModel->setSourceModel(mCollectionTree);
@@ -235,7 +225,7 @@ MainWidget::MainWidget(KXMLGUIClient *guiClient, QWidget *parent)
     connect(mCollectionView, qOverload<const Akonadi::Collection &>(&Akonadi::EntityTreeView::currentChanged),
             this, &MainWidget::slotCurrentCollectionChanged);
 
-    KSelectionProxyModel *selectionProxyModel
+    auto *selectionProxyModel
         = new KSelectionProxyModel(mCollectionSelectionModel, this);
     selectionProxyModel->setSourceModel(GlobalContactModel::instance()->model());
     selectionProxyModel->setFilterBehavior(KSelectionProxyModel::ChildrenOfExactSelection);
@@ -256,13 +246,17 @@ MainWidget::MainWidget(KXMLGUIClient *guiClient, QWidget *parent)
     mContactsFilterModel = new Akonadi::ContactsFilterProxyModel(this);
     mContactsFilterModel->setSourceModel(mCategoryFilterModel);
 
+    auto *contactInfoProxyModel = new ContactInfoProxyModel(this);
+    contactInfoProxyModel->setSourceModel(mContactsFilterModel);
+
     connect(mQuickSearchWidget, &QuickSearchWidget::filterStringChanged,
             mContactsFilterModel, &Akonadi::ContactsFilterProxyModel::setFilterString);
     connect(mQuickSearchWidget, &QuickSearchWidget::filterStringChanged,
             this, &MainWidget::selectFirstItem);
     connect(mQuickSearchWidget, &QuickSearchWidget::arrowDownKeyPressed,
             this, &MainWidget::setFocusToTreeView);
-    mItemView->setModel(mContactsFilterModel);
+    mItemView->setModel(contactInfoProxyModel);
+    mItemView->setItemDelegate(new StyleContactListDelegate(this));
     mItemView->setXmlGuiClient(guiClient);
     mItemView->setSelectionMode(QAbstractItemView::ExtendedSelection);
     mItemView->setRootIsDecorated(false);
@@ -336,13 +330,13 @@ void MainWidget::setFocusToTreeView()
 
 void MainWidget::initializeImportExportPlugin(KActionCollection *collection)
 {
-    const QVector<KAddressBookImportExport::KAddressBookImportExportPlugin *> listPlugins = KAddressBookImportExport::KAddressBookImportExportPluginManager::self()->pluginsList();
+    const QVector<KAddressBookImportExport::Plugin *> listPlugins = KAddressBookImportExport::PluginManager::self()->pluginsList();
     QList<QAction *> importActions;
     QList<QAction *> exportActions;
-    for (KAddressBookImportExport::KAddressBookImportExportPlugin *plugin : listPlugins) {
+    for (KAddressBookImportExport::Plugin *plugin : listPlugins) {
         if (plugin->isEnabled()) {
-            KAddressBookImportExport::KAddressBookImportExportPluginInterface *interface
-                = static_cast<KAddressBookImportExport::KAddressBookImportExportPluginInterface *>(plugin->createInterface(this));
+            auto *interface
+                = static_cast<KAddressBookImportExport::PluginInterface *>(plugin->createInterface(this));
             interface->setItemSelectionModel(mItemView->selectionModel());
             interface->setParentWidget(this);
             interface->createAction(collection);
@@ -393,7 +387,7 @@ void MainWidget::handleCommandLine(const QStringList &arguments)
         const QStringList lst = parser.positionalArguments();
         for (const QString &urlStr : lst) {
             const QUrl url(QUrl::fromUserInput(urlStr));
-            for (KAddressBookImportExport::KAddressBookImportExportPluginInterface *interface : qAsConst(mImportExportPluginInterfaceList)) {
+            for (KAddressBookImportExport::PluginInterface *interface : qAsConst(mImportExportPluginInterfaceList)) {
                 if (interface->canImportFileType(url)) {
                     interface->importFile(url);
                     break;
@@ -418,7 +412,7 @@ void MainWidget::delayedInit()
     setViewMode(0);                                        // get default from settings
 
     const KConfigGroup group(Settings::self()->config(), "UiState_ContactView");
-    KPIM::UiStateSaver::restoreState(mItemView, group);
+    KAddressBook::UiStateSaver::restoreState(mItemView, group);
 
     mXmlGuiClient->actionCollection()->action(QStringLiteral("options_show_qrcodes"))->setChecked(showQRCodes());
 
@@ -439,7 +433,7 @@ MainWidget::~MainWidget()
     saveSplitterStates();
 
     KConfigGroup group(Settings::self()->config(), "UiState_ContactView");
-    KPIM::UiStateSaver::saveState(mItemView, group);
+    KAddressBook::UiStateSaver::saveState(mItemView, group);
 
     saveState();
     delete mGrantleeThemeManager;
@@ -453,7 +447,7 @@ void MainWidget::restoreState()
 {
     // collection view
     {
-        Akonadi::ETMViewStateSaver *saver = new Akonadi::ETMViewStateSaver;
+        auto *saver = new Akonadi::ETMViewStateSaver;
         saver->setView(mCollectionView);
 
         const KConfigGroup group(Settings::self()->config(), "CollectionViewState");
@@ -462,7 +456,7 @@ void MainWidget::restoreState()
 
     // collection view
     {
-        Akonadi::ETMViewStateSaver *saver = new Akonadi::ETMViewStateSaver;
+        auto *saver = new Akonadi::ETMViewStateSaver;
         saver->setSelectionModel(mCollectionSelectionModel);
 
         const KConfigGroup group(Settings::self()->config(), "CollectionViewCheckState");
@@ -471,7 +465,7 @@ void MainWidget::restoreState()
 
     // item view
     {
-        Akonadi::ETMViewStateSaver *saver = new Akonadi::ETMViewStateSaver;
+        auto *saver = new Akonadi::ETMViewStateSaver;
         saver->setView(mItemView);
         saver->setSelectionModel(mItemView->selectionModel());
 
@@ -523,7 +517,7 @@ void MainWidget::saveState()
 void MainWidget::setupGui()
 {
     // the horizontal main layout
-    QHBoxLayout *layout = new QHBoxLayout(this);
+    auto *layout = new QHBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
 
     // Splitter 1 contains the two main parts of the GUI:
@@ -564,7 +558,7 @@ void MainWidget::setupGui()
     mMainWidgetSplitter2->setChildrenCollapsible(false);
     mMainWidgetSplitter1->setChildrenCollapsible(false);
 
-    QVBoxLayout *detailsPaneLayout = new QVBoxLayout(mDetailsPane);
+    auto *detailsPaneLayout = new QVBoxLayout(mDetailsPane);
     detailsPaneLayout->setContentsMargins(0, 0, 0, 0);
 
     // the details view stack
@@ -596,7 +590,7 @@ void MainWidget::setupGui()
     mCategorySelectWidget = new CategorySelectWidget;
 
     // setup the default actions
-    Akonadi::ContactDefaultActions *actions = new Akonadi::ContactDefaultActions(this);
+    auto *actions = new Akonadi::ContactDefaultActions(this);
     actions->connectToView(mContactDetails);
     actions->connectToView(mContactGroupDetails);
     mFormatter = new KAddressBookGrantlee::GrantleeContactFormatter;
@@ -616,7 +610,7 @@ void MainWidget::initializePluginActions()
 
 void MainWidget::slotImportExportActivated(PimCommon::AbstractGenericPluginInterface *interface)
 {
-    KAddressBookImportExport::KAddressBookImportExportPluginInterface *importExportInterface = static_cast<KAddressBookImportExport::KAddressBookImportExportPluginInterface *>(interface);
+    auto *importExportInterface = static_cast<KAddressBookImportExport::PluginInterface *>(interface);
     if (importExportInterface) {
         importExportInterface->exec();
     }
@@ -640,7 +634,7 @@ void MainWidget::setupActions(KActionCollection *collection)
     collection->addAction(QStringLiteral("theme_menu"), themeMenu);
 
     initGrantleeThemeName();
-    QActionGroup *group = new QActionGroup(this);
+    auto *group = new QActionGroup(this);
     mGrantleeThemeManager->setThemeMenu(themeMenu);
     mGrantleeThemeManager->setActionGroup(group);
 
@@ -651,12 +645,12 @@ void MainWidget::setupActions(KActionCollection *collection)
 
     KStandardAction::printPreview(this, &MainWidget::printPreview, collection);
 
-    QWidgetAction *quicksearch = new QWidgetAction(this);
+    auto *quicksearch = new QWidgetAction(this);
     quicksearch->setText(i18n("Quick search"));
     quicksearch->setDefaultWidget(mQuickSearchWidget);
     collection->addAction(QStringLiteral("quick_search"), quicksearch);
 
-    QWidgetAction *categoryFilter = new QWidgetAction(this);
+    auto *categoryFilter = new QWidgetAction(this);
     categoryFilter->setText(i18n("Category filter"));
     categoryFilter->setDefaultWidget(mCategorySelectWidget);
     collection->addAction(QStringLiteral("category_filter"), categoryFilter);
@@ -667,7 +661,7 @@ void MainWidget::setupActions(KActionCollection *collection)
     action->setWhatsThis(i18n("Select all contacts in the current address book view."));
     connect(action, &QAction::triggered, mItemView, &Akonadi::EntityTreeView::selectAll);
 
-    KToggleAction *qrtoggleAction = collection->add<KToggleAction>(QStringLiteral("options_show_qrcodes"));
+    auto *qrtoggleAction = collection->add<KToggleAction>(QStringLiteral("options_show_qrcodes"));
     qrtoggleAction->setText(i18n("Show QR Codes"));
     qrtoggleAction->setWhatsThis(i18n("Show QR Codes in the contact."));
     connect(qrtoggleAction, &KToggleAction::toggled, this, &MainWidget::setQRCodeShow);
@@ -838,8 +832,8 @@ void MainWidget::setQRCodeShow(bool on)
 Akonadi::Item::List MainWidget::selectedItems()
 {
     Akonadi::Item::List items;
-    QPointer<KAddressBookImportExport::KAddressBookContactSelectionDialog> dlg
-        = new KAddressBookImportExport::KAddressBookContactSelectionDialog(mItemView->selectionModel(), false, this);
+    QPointer<KAddressBookImportExport::ContactSelectionDialog> dlg
+        = new KAddressBookImportExport::ContactSelectionDialog(mItemView->selectionModel(), false, this);
     dlg->setDefaultAddressBook(currentAddressBook());
     if (!dlg->exec() || !dlg) {
         delete dlg;
@@ -868,7 +862,7 @@ Akonadi::Collection MainWidget::currentAddressBook() const
 QAbstractItemModel *MainWidget::allContactsModel()
 {
     if (!mAllContactsModel) {
-        KDescendantsProxyModel *descendantsModel = new KDescendantsProxyModel(this);
+        auto *descendantsModel = new KDescendantsProxyModel(this);
         descendantsModel->setSourceModel(GlobalContactModel::instance()->model());
 
         mAllContactsModel = new Akonadi::EntityMimeTypeFilterModel(this);
@@ -934,8 +928,8 @@ void MainWidget::saveSplitterStates() const
     const QString groupName = QStringLiteral("UiState_MainWidgetSplitter_%1").arg(currentMode);
     //qCDebug(KADDRESSBOOK_LOG) << "saving to group" << groupName;
     KConfigGroup group(Settings::self()->config(), groupName);
-    KPIM::UiStateSaver::saveState(mMainWidgetSplitter1, group);
-    KPIM::UiStateSaver::saveState(mMainWidgetSplitter2, group);
+    KAddressBook::UiStateSaver::saveState(mMainWidgetSplitter1, group);
+    KAddressBook::UiStateSaver::saveState(mMainWidgetSplitter2, group);
 }
 
 void MainWidget::restoreSplitterStates()
@@ -950,8 +944,8 @@ void MainWidget::restoreSplitterStates()
     const QString groupName = QStringLiteral("UiState_MainWidgetSplitter_%1").arg(currentMode);
     //qCDebug(KADDRESSBOOK_LOG) << "restoring from group" << groupName;
     KConfigGroup group(Settings::self()->config(), groupName);
-    KPIM::UiStateSaver::restoreState(mMainWidgetSplitter1, group);
-    KPIM::UiStateSaver::restoreState(mMainWidgetSplitter2, group);
+    KAddressBook::UiStateSaver::restoreState(mMainWidgetSplitter1, group);
+    KAddressBook::UiStateSaver::restoreState(mMainWidgetSplitter2, group);
 }
 
 void MainWidget::initGrantleeThemeName()
@@ -981,9 +975,9 @@ void MainWidget::slotGrantleeThemesUpdated()
 
 Akonadi::EntityTreeModel *MainWidget::entityTreeModel() const
 {
-    QAbstractProxyModel *proxy = qobject_cast<QAbstractProxyModel *>(mCollectionView->model());
+    auto *proxy = qobject_cast<QAbstractProxyModel *>(mCollectionView->model());
     while (proxy) {
-        Akonadi::EntityTreeModel *etm = qobject_cast<Akonadi::EntityTreeModel *>(proxy->sourceModel());
+        auto *etm = qobject_cast<Akonadi::EntityTreeModel *>(proxy->sourceModel());
         if (etm) {
             return etm;
         }
@@ -1061,7 +1055,7 @@ void MainWidget::slotServerSideSubscription()
 {
     Akonadi::Collection collection = currentAddressBook();
     if (collection.isValid()) {
-        PimCommon::ManageServerSideSubscriptionJob *job = new PimCommon::ManageServerSideSubscriptionJob(this);
+        auto *job = new PimCommon::ManageServerSideSubscriptionJob(this);
         job->setCurrentCollection(collection);
         job->setParentWidget(this);
         job->start();
@@ -1070,7 +1064,7 @@ void MainWidget::slotServerSideSubscription()
 
 void MainWidget::slotCurrentCollectionChanged(const Akonadi::Collection &col)
 {
-    for (KAddressBookImportExport::KAddressBookImportExportPluginInterface *interface : qAsConst(mImportExportPluginInterfaceList)) {
+    for (auto *interface : qAsConst(mImportExportPluginInterfaceList)) {
         interface->setDefaultCollection(col);
     }
     bool isOnline;
